==> jc-train-cuizheng2-metadata-2.0.279-sources.jar: com/xforceplus/ultraman/app/jctraincuizheng2/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.jctraincuizheng2.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2021-11-05
 */

public class PageMeta {
    public interface Autotestliebiao2 {
        static String code() {
            return "autotestliebiao2";
        }
        static String name() {
            return "autotestliebiao2";
        }
    }
    public interface Autotestliebiao3 {
        static String code() {
            return "autotestliebiao3";
        }
        static String name() {
            return "autotestliebiao3";
        }
    }
    public interface Autotestliebiao7 {
        static String code() {
            return "autotestliebiao7";
        }
        static String name() {
            return "autotestliebiao7";
        }
    }
    public interface Autotestliebiao0823 {
        static String code() {
            return "autotestliebiao0823";
        }
        static String name() {
            return "autotestliebiao0823";
        }
    }
    public interface Autotestgongshi {
        static String code() {
            return "autotestgongshi";
        }
        static String name() {
            return "autotestgongshi";
        }
    }
    public interface Test26 {
        static String code() {
            return "test26";
        }
        static String name() {
            return "test26";
        }
    }
    public interface Autotestzifuchuan {
        static String code() {
            return "autotestzifuchuan";
        }
        static String name() {
            return "autotestzifuchuan";
        }
    }
    public interface Autotestduozhizfc {
        static String code() {
            return "autotestduozhizfc";
        }
        static String name() {
            return "autotestduozhizfc";
        }
    }
    public interface Autotestchunshuzibianhao {
        static String code() {
            return "autotestchunshuzibianhao";
        }
        static String name() {
            return "autotestchunshuzibianhao";
        }
    }
    public interface Autotestzhengxing {
        static String code() {
            return "autotestzhengxing";
        }
        static String name() {
            return "autotestzhengxing";
        }
    }
    public interface Autotestfudianxing {
        static String code() {
            return "autotestfudianxing";
        }
        static String name() {
            return "autotestfudianxing";
        }
    }
    public interface Autotestbuerzhi {
        static String code() {
            return "autotestbuerzhi";
        }
        static String name() {
            return "autotestbuerzhi";
        }
    }
    public interface Autotestshijianchuo {
        static String code() {
            return "autotestshijianchuo";
        }
        static String name() {
            return "autotestshijianchuo";
        }
    }
    public interface Autotestmeijuxing {
        static String code() {
            return "autotestmeijuxing";
        }
        static String name() {
            return "autotestmeijuxing";
        }
    }
    public interface Autotestdzmeijuxing {
        static String code() {
            return "autotestdzmeijuxing";
        }
        static String name() {
            return "autotestdzmeijuxing";
        }
    }
    public interface Yanzhenglist1012 {
        static String code() {
            return "yanzhenglist1012";
        }
        static String name() {
            return "yanzhenglist1012";
        }
    }
    public interface Test {
        static String code() {
            return "test";
        }
        static String name() {
            return "test";
        }
    }
    public interface Autost20211101155644481133 {
        static String code() {
            return "autost20211101155644481133";
        }
        static String name() {
            return "新增视图20211101155644481133";
        }
    }
    public interface Autotestshitu {
        static String code() {
            return "autotestshitu";
        }
        static String name() {
            return "autotestshitu";
        }
    }
    public interface Autotestshitu2 {
        static String code() {
            return "autotestshitu2";
        }
        static String name() {
            return "autotestshitu2";
        }
    }
}

==> jc-train-cuizheng2-metadata-2.0.305-sources.jar: com/xforceplus/ultraman/app/jctraincuizheng2/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.jctraincuizheng2.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2021-11-10
 */

public class PageMeta {
    public interface Autotestliebiao2 {
        static String code() {
            return "autotestliebiao2";
        }
        static String name() {
            return "autotestliebiao2";
        }
    }
    public interface Autotestliebiao3 {
        static String code() {
            return "autotestliebiao3";
        }
        static String name() {
            return "autotestliebiao3";
        }
    }
    public interface Autotestliebiao7 {
        static String code() {
            return "autotestliebiao7";
        }
        static String name() {
            return "autotestliebiao7";
        }
    }
    public interface Autotestliebiao0823 {
        static String code() {
            return "autotestliebiao0823";
        }
        static String name() {
            return "autotestliebiao0823";
        }
    }
    public interface Autotestgongshi {
        static String code() {
            return "autotestgongshi";
        }
        static String name() {
            return "autotestgongshi";
        }
    }
    public interface Test26 {
        static String code() {
            return "test26";
        }
        static String name() {
            return "test26";
        }
    }
    public interface Autotestzifuchuan {
        static String code() {
            return "autotestzifuchuan";
        }
        static String name() {
            return "autotestzifuchuan";
        }
    }
    public interface Autotestduozhizfc {
        static String code() {
            return "autotestduozhizfc";
        }
        static String name() {
            return "autotestduozhizfc";
        }
    }
    public interface Autotestchunshuzibianhao {
        static String code() {
            return "autotestchunshuzibianhao";
        }
        static String name() {
            return "autotestchunshuzibianhao";
        }
    }
    public interface Autotestzhengxing {
        static String code() {
            return "autotestzhengxing";
        }
        static String name() {
            return "autotestzhengxing";
        }
    }
    public interface Autotestfudianxing {
        static String code() {
            return "autotestfudianxing";
        }
        static String name() {
            return "autotestfudianxing";
        }
    }
    public interface Autotestbuerzhi {
        static String code() {
            return "autotestbuerzhi";
        }
        static String name() {
            return "autotestbuerzhi";
        }
    }
    public interface Autotestshijianchuo {
        static String code() {
            return "autotestshijianchuo";
        }
        static String name() {
            return "autotestshijianchuo";
        }
    }
    public interface Autotestmeijuxing {
        static String code() {
            return "autotestmeijuxing";
        }
        static String name() {
            return "autotestmeijuxing";
        }
    }
    public interface Autotestdzmeijuxing {
        static String code() {
            return "autotestdzmeijuxing";
        }
        static String name() {
            return "autotestdzmeijuxing";
        }
    }
    public interface Yanzhenglist1012 {
        static String code() {
            return "yanzhenglist1012";
        }
        static String name() {
            return "yanzhenglist1012";
        }
    }
    public interface Test {
        static String code() {
            return "test";
        }
        static String name() {
            return "test";
        }
    }
    public interface Autost20211101155644481133 {
        static String code() {
            return "autost20211101155644481133";
        }
        static String name() {
            return "新增视图20211101155644481133";
        }
    }
    public interface Autotestshitu {
        static String code() {
            return "autotestshitu";
        }
        static String name() {
            return "autotestshitu";
        }
    }
    public interface Autotestshitu2 {
        static String code() {
            return "autotestshitu2";
        }
        static String name() {
            return "autotestshitu2";
        }
    }
    public interface Autost20211108100110697748 {
        static String code() {
            return "autost20211108100110697748";
        }
        static String name() {
            return "新增视图20211108100110697711";
        }
    }
    public interface Autost20211108115508501236 {
        static String code() {
            return "autost20211108115508501236";
        }
        static String name() {
            return "新增视图20211108115508501201";
        }
    }
    public interface Autost20211108141540932170 {
        static String code() {
            return "autost20211108141540932170";
        }
        static String name() {
            return "新增视图20211108141540932129";
        }
    }
    public interface Autost20211108143930567407 {
        static String code() {
            return "autost20211108143930567407";
        }
        static String name() {
            return "新增视图20211108143930567368";
        }
    }
    public interface Autost20211109080848133930 {
        static String code() {
            return "autost20211109080848133930";
        }
        static String name() {
            return "新增视图20211109080848133899";
        }
    }
}
